"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var react_2 = require("@testing-library/react");
var regular_1 = require("../regular");
var emotion_theming_1 = require("emotion-theming");
var theme_1 = __importDefault(require("../../../styles/theme"));
describe('<Button /> spec', function () {
    test('it renders the component', function () {
        // Arrange
        var buttonText = 'Click me';
        // Act
        var getByText = react_2.render(react_1.default.createElement(regular_1.Button, null, buttonText)).getByText;
        // Assert
        expect(getByText(buttonText)).toMatchSnapshot();
    });
    test('that click gets handled', function () {
        // Arrange
        var buttonText = "Click me";
        jest.spyOn(window, 'alert').mockImplementation(function () { });
        var clickHandler = function () { return window.alert("Alerting you"); };
        // Act
        var getByText = react_2.render(react_1.default.createElement(regular_1.Button, { onClick: clickHandler }, buttonText)).getByText;
        react_2.fireEvent.click(getByText(buttonText));
        // Assert
        expect(window.alert).toHaveBeenCalledTimes(1);
    });
    test('that <Button /> has correct background', function () {
        // Arrange
        var buttonText = 'Click me';
        var variant = "secondary";
        // Act 
        var getByText = react_2.render(react_1.default.createElement(emotion_theming_1.ThemeProvider, { theme: theme_1.default },
            react_1.default.createElement(regular_1.Button, { variant: variant }, buttonText))).getByText;
        var button = getByText(buttonText);
        var style = window.getComputedStyle(button);
        // Assert
        expect(style.backgroundColor).toBe(theme_1.default.colors.secondary);
    });
});
